@@ -113,7 +113,7 @@ extern "C" {
     #define restrict 
 #endif
 
-/*    OpenMP < 3.0 (e.g. MSVC as of 2020) does not support parallel for's with unsigned iterators,
+/*  OpenMP < 3.0 (e.g. MSVC as of 2020) does not support parallel for's with unsigned iterators,
     and does not support declaring the iterator type in the loop itself */
 #ifdef _OPENMP
     #if (_OPENMP < 200801) || defined(_WIN32) || defined(_WIN64) /* OpenMP < 3.0 */
@@ -230,11 +230,13 @@ void cblas_tsymv(const CBLAS_ORDER order, const CBLAS_UPLO Uplo, const int_t N,
 #define cap_to_4(x) (((x) > 4)? 4 : (x))
 #define max2(a, b) ((a) >= ((b))? (a) : (b))
 #define min2(a, b) ((a) <= ((b))? (a) : (b))
+#define set_to_zero(arr, n) memset((arr), 0, (size_t)(n)*sizeof(real_t))
+#define copy_arr(from, to, n) memcpy((to), (from), (size_t)(n)*sizeof(real_t))
 
 
 /* helpers.c */
-void set_to_zero(real_t *arr, const size_t n, int_t nthreads);
-void copy_arr(real_t *restrict src, real_t *restrict dest, size_t n, int_t nthreads);
+void set_to_zero_(real_t *arr, const size_t n, int_t nthreads);
+void copy_arr_(real_t *restrict src, real_t *restrict dest, size_t n, int_t nthreads);
 int_t count_NAs(real_t arr[], size_t n, int_t nthreads);
 void count_NAs_by_row
 (
@@ -1851,7 +1853,7 @@ int_t fit_offsets_implicit_als
 int_t matrix_content_based
 (
     real_t *restrict Am_new,
-    int_t n_new, int_t k_sec,
+    int_t m_new, int_t k,
     real_t *restrict U, int_t p,
     int_t U_row[], int_t U_col[], real_t *restrict U_sp, size_t nnz_U,
     size_t U_csr_p[], int_t U_csr_i[], real_t *restrict U_csr,
